# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011, 2012, 2013,
#               2015 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.

"""Invenio Search Engine config parameters."""

import os

import pkg_resources

SEARCH_QUERY_PARSER = 'invenio_query_parser.parser:Main'

SEARCH_QUERY_WALKERS = [
    'invenio_query_parser.walkers.pypeg_to_ast:PypegConverter',
]

# SEARCH_QUERY_ENHANCERS -- a comma separated list of strings. Each string is a
# function that is applied to the AST generated by the parser and enhances the
# query tree
SEARCH_QUERY_ENHANCERS = [
    # 'invenio_search.enhancers.collection_filter.apply',
]

# SEARCH_WALKERS -- a comma separated list of strings. Each string is
# a AST visitor class.
SEARCH_WALKERS = [
    'invenio_search.walkers.elasticsearch:ElasticSearchDSL',
]

#
# ELASTIC configuration
#

# SEARCH_ELASTIC_HOSTS -- list of hosts for Elasticsearch client.
# http://elasticsearch-py.readthedocs.org/en/master/api.html#elasticsearch.Elasticsearch
if os.environ.get('SEARCH_ELASTIC_HOSTS'):  # pragma: no cover
    SEARCH_ELASTIC_HOSTS = os.environ.get('SEARCH_ELASTIC_HOSTS').split(',')
else:
    SEARCH_ELASTIC_HOSTS = None  # default localhost

# SEARCH_INDEX_DEFAULT -- use when no index name is defined
SEARCH_INDEX_DEFAULT = 'records'

# SEARCH_AUTOINDEX -- list of functions that put data in Elasticsearch.
SEARCH_AUTOINDEX = []
try:
    pkg_resources.get_distribution('invenio_records')
    SEARCH_AUTOINDEX.append(  # pragma: no cover
        'invenio_search.contrib.records:index_record_modification')
except pkg_resources.DistributionNotFound:  # pragma: no cover
    pass


# SEARCH_ELASTIC_KEYWORD_MAPPING -- this variable holds a dictionary to map
# invenio keywords to elasticsearch fields
SEARCH_ELASTIC_KEYWORD_MAPPING = {
    None: ["_all"],
    "author": {
        'a': ["main_entry_personal_name.personal_name",
              "added_entry_personal_name.personal_name"],
        'p': ["main_entry_personal_name.personal_name",
              "added_entry_personal_name.personal_name"],
        'e': ['authors.raw'],
    },
    "collection": ["_collections"],
    "title": ["title_statement.title"],
    "980": [
        "collections.primary",
        "collections.secondary",
        "collections.deleted",
    ],
    "980__a": ["collections.primary"],
    "980__b": ["collections.secondary"],
    "542__l": ["information_relating_to_copyright_status.copyright_status"],
}
